@@ -13,7 +13,7 @@ class Test(TestCase):
         self.score = TreeScoreTimewise()
 
     def test_1(self):
-        sf = SimpleFormat(durations=[1, 1, 1])
+        sf = SimpleFormat(quarter_durations=[1, 1, 1])
 
         sf.chords[0].add_fermata()
         sf.chords[1].add_fermata('square')
